#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-BE0bCjHBwlwF8UMPTAqaKQ
key:                  haskell-language-server-2.3.0.0-BE0bCjHBwlwF8UMPTAqaKQ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  18fbf391ebed4cb96ea055059dab1797
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-BE0bCjHBwlwF8UMPTAqaKQ
depends:
    aeson-pretty-0.8.11-14Ddz3zmjAB9aNGz5rrQGd
    async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu base-4.18.2.1
    base16-bytestring-1.0.2.0-KkKTvweYtUjAEl7m2QLWFY
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Ah8gZa7EYGY3jjcblccB4t
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-aWEq6cZZ289lIc6yxljo5 filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-18sa3skFOT1HznOGP4KL4J
    githash-0.1.7.0-r4bUrTE9peHhLOF5h0oZD
    hie-bios-0.12.0-9LZjTbKos99kepC8phEe3
    hiedb-0.4.3.0-LOEUIBEoqo127RIdL6Lh7O
    hls-alternate-number-format-plugin-2.3.0.0-DGEAxrG6x6m44pqmCGdgjA
    hls-cabal-fmt-plugin-2.3.0.0-IQAycW8boQiI5Y9cSldsOX
    hls-cabal-plugin-2.3.0.0-B1FhfqBM4EE3TyBZHX645I
    hls-call-hierarchy-plugin-2.3.0.0-8en2zZheMuCGJxPeRlaHfo
    hls-change-type-signature-plugin-2.3.0.0-1IgdbCJ9V3NIgL8wxFCx03
    hls-class-plugin-2.3.0.0-J0HKxQ5AEbMDkJAF4jUTZu
    hls-code-range-plugin-2.3.0.0-AjZs045ag7EIRUqn7L0wu8
    hls-eval-plugin-2.3.0.0-8zgcoqmS6EPJQznoLv2i08
    hls-explicit-fixity-plugin-2.3.0.0-DUSUT9fK4YWHdBdNWRSDDK
    hls-explicit-imports-plugin-2.3.0.0-FmLvZKZY6abKoTXqfb1PJS
    hls-explicit-record-fields-plugin-2.3.0.0-FqJIo1jWXc07CrysaU8iNI
    hls-fourmolu-plugin-2.3.0.0-HnsNyiAFAsL3ku4yjS1JXX
    hls-gadt-plugin-2.3.0.0-AGu08CLlqznIDYTwMfK0mk
    hls-graph-2.3.0.0-2DkZepk2oez3n6Moqv5OBJ
    hls-hlint-plugin-2.3.0.0-MvS9A94zYIDnsPEYghAqs
    hls-module-name-plugin-2.3.0.0-J5leLt6U3AJIH0TBOYTx90
    hls-ormolu-plugin-2.3.0.0-1t4kyeGYcguIpO1AodSelQ
    hls-overloaded-record-dot-plugin-2.3.0.0-6Ecc4qMgeNNLUiNxaqg5pq
    hls-plugin-api-2.3.0.0-6FbyogaZUzQnICn9LIAaM
    hls-pragmas-plugin-2.3.0.0-D1ctYqJvnHKLwIignfsjPg
    hls-qualify-imported-names-plugin-2.3.0.0-IWnMLVARZXV9H2yI8drUee
    hls-refactor-plugin-2.3.0.0-ADruZTqDRts69534Sy7tP3
    hls-rename-plugin-2.3.0.0-6lSvA9plZ9mB8ajQvNPbtE
    hls-retrie-plugin-2.3.0.0-JJmBLVTOaBVHgnTykWhpZ2
    hls-splice-plugin-2.3.0.0-DsBllnr2t31KQ76BqOshoB
    hls-stylish-haskell-plugin-2.3.0.0-G1Z7fQQsXNGHG8IKWjlui7
    lsp-2.2.0.0-AMvH8uI6CvNFs6ZEiC2ocP
    optparse-applicative-0.18.1.0-5QX38E1JQlq4e4oHsAaFH0
    optparse-simple-0.1.1.4-4BCCIpDDcGU9xRHSFzmF5W
    prettyprinter-1.7.2-6Ih5s8mp5Rq22RoHimn1zv process-1.6.19.0
    safe-exceptions-0.1.7.4-LLCsXRZv4m2CGwiR6DBSct
    sqlite-simple-0.4.19.0-C0RNFTcVgtw5U6bFPwgDl1 text-2.0.2
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

